=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2006-01-05 22:30:59 +0000
+++ bzrlib/errors.py	2006-01-31 14:09:11 +0000
@@ -376,6 +376,16 @@
     """Text did not match it's checksum: %(message)s"""
 
 
+class WeaveTextDiffers(WeaveError):
+    """Weaves differ on text content. Revision: {%(revision_id)s}, %(weave_a)s, %(weave_b)s"""
+
+    def __init__(self, revision_id, weave_a, weave_b):
+        WeaveError.__init__(self)
+        self.revision_id = revision_id
+        self.weave_a = weave_a
+        self.weave_b = weave_b
+
+
 class NoSuchExportFormat(BzrNewError):
     """Export format %(format)r not supported"""
     def __init__(self, format):

=== modified file 'bzrlib/tests/test_weave.py'
--- bzrlib/tests/test_weave.py	2006-01-30 01:02:59 +0000
+++ bzrlib/tests/test_weave.py	2006-01-31 14:09:11 +0000
@@ -1053,3 +1053,19 @@
         w1.join(w2) # extract 3a to add txt2 
         w2.join(w1) # extract 3b to add txt1 
 
+
+class MismatchedTexts(TestCase):
+    """Test that merging two weaves with different texts fails."""
+
+    def test_reweave(self):
+        w1 = Weave('a')
+        w2 = Weave('b')
+
+        w1.add('txt0', [], ['a\n'])
+        w2.add('txt0', [], ['a\n'])
+        w1.add('txt1', [0], ['a\n', 'b\n'])
+        w2.add('txt1', [0], ['a\n', 'c\n'])
+
+        self.assertRaises(errors.WeaveTextDiffers, w1.reweave, w2)
+
+

=== modified file 'bzrlib/weave.py'
--- bzrlib/weave.py	2006-01-25 17:56:27 +0000
+++ bzrlib/weave.py	2006-01-31 14:09:11 +0000
@@ -946,7 +946,15 @@
         if name in wa._name_map:
             lines = wa.get_lines(name)
             if name in wb._name_map:
-                assert lines == wb.get_lines(name)
+                lines_b = wb.get_lines(name)
+                if lines != lines_b:
+                    mutter('Weaves differ on content. rev_id {%s}', name)
+                    mutter('weaves: %s, %s', wa._weave_name, wb._weave_name)
+                    import difflib
+                    lines = list(difflib.unified_diff(lines, lines_b,
+                            wa._weave_name, wb._weave_name))
+                    mutter('lines:\n%s', ''.join(lines))
+                    raise errors.WeaveTextDiffers(name, wa, wb)
         else:
             lines = wb.get_lines(name)
         wr.add(name, combined_parents[name], lines)

